==> github-widget2-1.0.0.tgz: package/lib/test/orgs.test.js <==
'use strict';

var _jsxFileName = '../../src/test/orgs.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Organizations = require('../components/Organizations/Organizations');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        orgs: {
          ids: ['246869449'],
          orgsById: {
            246869449: {
              avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
              orgName: 'ShareCastG52',
              reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
            }
          }
        },
        currentPage: { render: 'orgs', repoName: null, userName: 'michaelmurray6298' }
      }
    },
    currentPage: { render: 'orgs', repoName: null }
  },
  currentPage: { render: 'orgs', repoName: null, userName: 'michaelmurray6298' }
};

describe('Organizations component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveOrgs = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Organizations.Organizations, {
      orgIds: state.widgets.byId.github.orgs.ids,
      loadingOrganizations: false,
      currentPage: state.widgets.byId.github.currentPage.render,
      retrieveOrgs: retrieveOrgs,
      userName: state.widgets.byId.github.currentPage.userName,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 37
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });
  // NOTE this test will be included in future versions
  // to check that passed in functions have been called
  // it('Should call the retrieveOrganizations Function', ()=> {
  //   const retrieveOrgs = jest.fn();
  //   const store = mockStore({ })
  //   const component = mount (
  //     <Organizations orgIds={state.orgs.ids}  retrieveOrgs={retrieveOrgs}/>,
  //   );
  //   expect(retrieveOrgs).toBeCalled();
  // });

  it("map's given State To Props ", function () {
    var expected = {
      orgIds: ['246869449'],
      orgsById: {
        246869449: {
          avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
          orgName: 'ShareCastG52',
          reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
        }
      },
      userName: 'michaelmurray6298'
    };
    expect((0, _Organizations.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Organizations.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveOrgs');
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/orgs.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Organizations = require('../components/Organizations/Organizations');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        orgs: {
          ids: ['246869449'],
          orgsById: {
            246869449: {
              avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
              orgName: 'ShareCastG52',
              reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
            }
          }
        },
        currentPage: { render: 'orgs', repoName: null, userName: 'michaelmurray6298' }
      }
    },
    currentPage: { render: 'orgs', repoName: null }
  },
  currentPage: { render: 'orgs', repoName: null, userName: 'michaelmurray6298' }
};

describe('Organizations component', function () {
  it('should render a component with props as specified ', function () {
    var retrieveOrgs = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Organizations.Organizations, {
      orgIds: state.widgets.byId.github.orgs.ids,
      loadingOrganizations: false,
      currentPage: state.widgets.byId.github.currentPage.render,
      retrieveOrgs: retrieveOrgs,
      userName: state.widgets.byId.github.currentPage.userName
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });
  // NOTE this test will be included in future versions
  // to check that passed in functions have been called
  // it('Should call the retrieveOrganizations Function', ()=> {
  //   const retrieveOrgs = jest.fn();
  //   const store = mockStore({ })
  //   const component = mount (
  //     <Organizations orgIds={state.orgs.ids}  retrieveOrgs={retrieveOrgs}/>,
  //   );
  //   expect(retrieveOrgs).toBeCalled();
  // });

  it("map's given State To Props ", function () {
    var expected = {
      orgIds: ['246869449'],
      orgsById: {
        246869449: {
          avatarUrl: 'https://avatars1.githubusercontent.com/u/29614654?v=4',
          orgName: 'ShareCastG52',
          reposUrl: 'https://api.github.com/orgs/ShareCastG52/repos'
        }
      },
      userName: 'michaelmurray6298'
    };
    expect((0, _Organizations.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _Organizations.mapDispatchToProps)(dispatch)).toHaveProperty('retrieveOrgs');
  });
});
